@@ -9,7 +9,7 @@ from easydata.parsers.base import Base, BaseData
 from easydata.parsers.data import Data
 from easydata.parsers.text import Text
 from easydata.parsers.url import Url
-from easydata.queries.base import QuerySearch
+from easydata.queries.base import QuerySearchBase
 from easydata.utils import email, mix
 
 __all__ = (
@@ -23,11 +23,11 @@ __all__ = (
 class List(BaseData):
     def __init__(
         self,
-        query: Optional[QuerySearch] = None,
+        query: Optional[QuerySearchBase] = None,
         parser: Optional[Base] = None,
         unique: bool = True,
         max_num: Optional[int] = None,
-        split_key: Optional[str] = None,
+        split_key: Optional[Union[ListType[str], str]] = None,
         preprocess_allow: Optional[Callable] = None,
         process_allow: Optional[Callable] = None,
         **kwargs,
@@ -60,7 +60,7 @@ class List(BaseData):
     def _default_parser_obj(self):
         return Data()
 
-    def _parse_value(self, value: Any, data: Any) -> list:
+    def parse_value(self, value: Any, data: Any) -> list:
 
         if value is None:
             return []
@@ -97,7 +97,7 @@ class List(BaseData):
             list_values = [list_values]
 
         if self._split_key:
-            list_values = mix.multiply_list_values(
+            list_values = mix.multiply_list_values_by_split_key(
                 list_values=list_values,
                 split_key=self._split_key,
             )
