@@ -1,7 +1,7 @@
 import json
 from abc import ABC, abstractmethod
 from functools import lru_cache
-from typing import Any, Dict, Iterator, List, Optional, Union
+from typing import Any, Dict, Iterator, List, Optional
 
 import xmltodict
 import yaml
@@ -12,8 +12,8 @@ from easydata.data import DataBag
 from easydata.parsers.base import BaseData
 from easydata.parsers.data import Data
 from easydata.processors.base import BaseProcessor
-from easydata.queries.base import QuerySearch
-from easydata.queries.re import ReQuery
+from easydata.queries.base import QuerySearchBase
+from easydata.queries.re import ReSearch
 from easydata.utils import parse
 
 __all__ = (
@@ -40,19 +40,29 @@ class DataBaseProcessor(BaseProcessor, ABC):
         source: str = "main",
         new_source: Optional[str] = None,
         process_source_data=None,
+        debug: bool = False,
+        debug_raw: bool = None,
     ):
 
         self._source = source
         self._new_source = new_source
         self._process_source_data = process_source_data
+        self._debug = debug
+        self._debug_raw = debug_raw
 
     def parse(self, data: DataBag) -> Iterator[DataBag]:
         source_data = data[self._source]
 
+        if self._debug_raw:
+            print(source_data)
+
         if self._process_source_data:
             source_data = self._process_source_data(source_data)
 
-        transformed_data = self._process_data(source_data)
+        transformed_data = self.process_data(source_data)
+
+        if self._debug:
+            print(transformed_data)
 
         if self._multi:
             for iter_transformed_data in transformed_data:
@@ -71,7 +81,7 @@ class DataBaseProcessor(BaseProcessor, ABC):
         return self.parse(data)
 
     @abstractmethod
-    def _process_data(self, source_data) -> Any:
+    def process_data(self, source_data) -> Any:
         pass
 
     def _transformed_data_to_data(self, transformed_data, data):
@@ -89,17 +99,17 @@ class DataBaseProcessor(BaseProcessor, ABC):
 
 
 class DataProcessor(DataBaseProcessor):
-    def _process_data(self, source_data) -> Any:
+    def process_data(self, source_data) -> Any:
         return source_data
 
 
 class DataToPqProcessor(DataBaseProcessor):
-    def _process_data(self, source_data: str) -> PyQuery:
+    def process_data(self, source_data: str) -> PyQuery:
         return PyQuery(source_data)
 
 
 class DataJsonToDictProcessor(DataBaseProcessor):
-    def _process_data(self, source_data: str) -> dict:
+    def process_data(self, source_data: str) -> dict:
         return json.loads(source_data)
 
 
@@ -115,11 +125,11 @@ class DataYamlToDictProcessor(DataBaseProcessor):
 
         super().__init__(*args, **kwargs)
 
-    def _process_data(self, source_data: str) -> dict:
+    def process_data(self, source_data: str) -> dict:
         if self._safe_load:
             return yaml.safe_load(source_data)
 
-        return yaml.load(source_data)
+        return yaml.load(source_data)  # type: ignore
 
 
 class DataXmlToDictProcessor(DataBaseProcessor):
@@ -166,7 +176,7 @@ class DataXmlToDictProcessor(DataBaseProcessor):
         config_key = "ED_DATA_XML_TO_DICT_ITEM_DEPTH"
         return self.__item_depth or self.config[config_key]
 
-    def _process_data(self, data: Any) -> Any:
+    def process_data(self, data: Any) -> Any:
         return xmltodict.parse(
             xml_input=data,
             encoding=self._encoding,
@@ -186,7 +196,7 @@ class DataXmlToDictProcessor(DataBaseProcessor):
 class DataFromQueryProcessor(DataBaseProcessor):
     def __init__(
         self,
-        query: Union[QuerySearch],
+        query: QuerySearchBase,
         **kwargs,
     ):
 
@@ -194,7 +204,7 @@ class DataFromQueryProcessor(DataBaseProcessor):
 
         super().__init__(**kwargs)
 
-    def _process_data(self, data: Any) -> Any:
+    def process_data(self, data: Any) -> Any:
         return parse.query_search(self._query, data)
 
 
@@ -204,7 +214,7 @@ class DataFromIterQueryProcessor(DataFromQueryProcessor):
 
 class DataJsonFromQueryToDictProcessor(DataFromQueryProcessor):
     def process_data(self, data: Any) -> Any:
-        jt = super()._process_data(data)
+        jt = super().process_data(data)
 
         return json.loads(jt)
 
@@ -233,8 +243,8 @@ class DataTextFromReProcessor(DataBaseProcessor):
 
         super().__init__(*args, **kwargs)
 
-    def _process_data(self, source_data: str) -> Any:
-        value = ReQuery(
+    def process_data(self, source_data: str) -> Any:
+        value = ReSearch(
             query=self._query,
             dotall=self._dotall,
             ignore_case=self._ignore_case,
@@ -261,8 +271,8 @@ class DataTextFromReProcessor(DataBaseProcessor):
 
 
 class DataJsonFromReToDictProcessor(DataTextFromReProcessor):
-    def _process_data(self, source_data: str) -> Any:
-        value = super()._process_data(source_data)
+    def process_data(self, source_data: str) -> Any:
+        value = super().process_data(source_data)
 
         if not value:
             return None
@@ -276,11 +286,11 @@ class DataJsonFromReToDictProcessor(DataTextFromReProcessor):
 class DataVariantsProcessor(DataBaseProcessor):
     def __init__(
         self,
-        query: Optional[QuerySearch] = None,
+        query: Optional[QuerySearchBase] = None,
         source: str = "main",
         parser: Optional[BaseData] = None,
         key_parser: Optional[BaseData] = None,
-        key_query: Optional[QuerySearch] = None,
+        key_query: Optional[QuerySearchBase] = None,
         **kwargs,
     ):
 
@@ -313,7 +323,7 @@ class DataVariantsProcessor(DataBaseProcessor):
     def _parser(self) -> Optional[BaseData]:
         return Data(self._query) if self._query else self.__parser
 
-    def _process_data(self, data: Any) -> Dict[Optional[str], Any]:
+    def process_data(self, data: Any) -> Dict[Optional[str], Any]:
         variants_data: Dict[Optional[str], Any] = {}
 
         parser = self._parser
