@@ -3,6 +3,7 @@ import pytest
 from easydata.data import DataBag
 from easydata.models import ItemModel
 from easydata.parsers.data import Data
+from easydata.parsers.text import Text
 from easydata.queries import jp
 from tests.factory import data_dict
 
@@ -65,6 +66,11 @@ def test_base_data_field_different_source(query, source, test_data, result):
     assert item_data.parse(test_data) == result
 
 
+def test_base_data_with_query_source():
+    item_data = Data(query=jp("stock", source="additional_data"))
+    assert item_data.parse(db) is True
+
+
 @pytest.mark.parametrize(
     "query, process_raw_value_callback, test_data, result",
     [
@@ -74,6 +80,12 @@ def test_base_data_field_different_source(query, source, test_data, result):
             db,
             "EasyBook pro 13",
         ),
+        (
+            jp("info.name"),
+            Text(replace_keys=[("15", "13")]),
+            db,
+            "EasyBook pro 13",
+        ),
         (jp("info.name"), process_raw_value, db, "EasyBook pro 15 True"),
     ],
 )
@@ -96,6 +108,12 @@ def test_base_data_field_process_raw_value(
             db,
             "EasyBook pro 15 True",
         ),
+        (
+            None,
+            Text(remove_keys=["'"], split_keys=[("Easy", -1), "pro"]),
+            "EasyBook' pro 15",
+            "Book",
+        ),
         (jp("info.name"), process_raw_value, db, "EasyBook pro 15 True"),
     ],
 )
