@@ -3,8 +3,9 @@ import json
 import pytest
 from pyquery import PyQuery
 
+import easydata as ed
 from easydata.data import DataBag
-from easydata.queries import re
+from easydata.exceptions import QuerySearchDataEmpty, QuerySearchResultNotFound
 
 json_text = """
 let spConfig = {
@@ -34,18 +35,18 @@ html_text = "<div><p>EasyData</p></div>"
     ],
 )
 def test_re_query(query, test_data, source, result):
-    assert re(query).get(test_data, source) == result
+    assert ed.re(query).get(test_data, source) == result
 
 
 def test_re_query_wrong_type_exception():
     with pytest.raises(TypeError) as excinfo:
-        re('basePrice": "(.*?)"').get(json)
+        ed.re('basePrice": "(.*?)"').get(json)
 
     assert "provided data" in str(excinfo.value).lower()
 
 
 def test_re_query_ignore_case():
-    re_query = re(
+    re_query = ed.re(
         query='"baseprice": "(.*?)"',
         ignore_case=True,
     )
@@ -61,7 +62,7 @@ def test_re_query_ignore_case():
     ],
 )
 def test_re_query_dotall_ignore_case(query, dotall, ignore_case, result):
-    re_query = re(query=query, dotall=dotall, ignore_case=ignore_case)
+    re_query = ed.re(query=query, dotall=dotall, ignore_case=ignore_case)
 
     json_result = re_query.get(json_text, "main")
 
@@ -73,18 +74,28 @@ def test_re_query_dotall_ignore_case(query, dotall, ignore_case, result):
 
 
 def test_re_query_multiline_ignore_case():
-    json_result_text = re("spConfig = (.*?);").get(json_text, "main")
+    json_result_text = ed.re("spConfig = (.*?);").get(json_text, "main")
     json_data = json.loads(json_result_text)
 
     assert json_data["basePrice"] == "149.95"
 
 
 def test_re_query_get_list():
-    assert re('"basePrice": "(.*?)"::all').get(json_text, "main") == ["149.95", "0"]
+    assert ed.re('"basePrice": "(.*?)"::all').get(json_text, "main") == ["149.95", "0"]
 
 
 def test_re_query_missing_pattern_with_pseudo_key_all_exception():
     with pytest.raises(ValueError) as excinfo:
-        re("::all").get(json_text, "main")
+        ed.re("::all").get(json_text, "main")
 
     assert "regex pattern is required beside ::all" in str(excinfo.value).lower()
+
+
+def test_re_query_strict_query_non_existent_error():
+    with pytest.raises(QuerySearchResultNotFound):
+        assert ed.re_strict('basePrice2": "(.*?)"').get(json_text)
+
+
+def test_re_query_strict_data_empty_error():
+    with pytest.raises(QuerySearchDataEmpty):
+        assert ed.re_strict('basePrice": "(.*?)"').get(None)
